var NAVTREEINDEX0 =
{
"Triangulation_on_sphere_2_2triang_on_sphere_8cpp-example.html":[4,0],
"Triangulation_on_sphere_2_2triang_on_sphere_exact_8cpp-example.html":[4,1],
"Triangulation_on_sphere_2_2triang_on_sphere_proj_8cpp-example.html":[4,2],
"Triangulation_on_sphere_2_2triang_on_sphere_range_8cpp-example.html":[4,3],
"annotated.html":[3],
"citelist.html":[2],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html":[1,0,1,0],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a0b1d32e620b7522606670b0ed5858142":[1,0,1,0,10],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a176258dbf24328ac4d3fde54e5eb0b26":[1,0,1,0,20],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a1fff40c879ca8ba44d14d354ecf2200b":[1,0,1,0,4],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a295dfed8bd54faa5c2404c09e30acdda":[1,0,1,0,1],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a34509a2547240f9234c76e941c842cce":[1,0,1,0,22],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a4ec4a8d0adec85a5e68eeb73951b901c":[1,0,1,0,21],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a528b38fdbcf384953e90e3514fc398ac":[1,0,1,0,16],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a6e74342e90b637989353e97658aaac85":[1,0,1,0,13],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a714ebac8bf8ff3042644f84492f8d3fb":[1,0,1,0,9],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a74de0d03004d394d3d51c7def896c595":[1,0,1,0,5],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a8a599356d6fb101aa7122b8fb88b168a":[1,0,1,0,17],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#a917507c1f208bda4e103ff6e968311f8":[1,0,1,0,8],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aaf23cbd9fef31230bf4c2cbc6fc11f8e":[1,0,1,0,2],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab04c29d1196edf08823156ac4acfa3d7":[1,0,1,0,12],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ab67e4c0620b7c500e0d7629a6e256af7":[1,0,1,0,14],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aba2ab15d0e6b0c0f7f71a1767b5b5aca":[1,0,1,0,0],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ac7403a86022a535d14d75ce3a0b84370":[1,0,1,0,11],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad4514b958d3e833cb77d1d288dc83b14":[1,0,1,0,18],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad4cb73f08b56a1ca41c9734a37a6dbf9":[1,0,1,0,19],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad69bbc3e97aa9b346e87b9f1ae7fc3a0":[1,0,1,0,7],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#ad8b32d8bc75e9fb527e7069a0ced7a70":[1,0,1,0,6],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#aea2f440a6add710a1aecee7e841b1013":[1,0,1,0,15],
"classCGAL_1_1Delaunay__triangulation__on__sphere__2.html#afa69966c7ebbb4fe172d962d4d38ff67":[1,0,1,0,3],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html":[1,0,1,1],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a0382911b98a55b2ee4bdb2ac493961a0":[1,0,1,1,12],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a21eb6038d4b9418605495ac5b05b9005":[1,0,1,1,6],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a2579d79f9c9480f3c16b9e509d9126ab":[1,0,1,1,11],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a33d5d7ac61c7efdf986672dcacd91f43":[1,0,1,1,10],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a444ba203f293262bf9b0747ecd872d69":[1,0,1,1,13],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a69798fee2314576e1a4b7b8f284d7f16":[1,0,1,1,4],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a6ccbd74fd9565dc73976c30af9648a59":[1,0,1,1,8],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a740e41f4f0980eb4e3a1637071d17e09":[1,0,1,1,15],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a7a14aee6791eda7fa5bc3f2c55055e07":[1,0,1,1,14],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a7d9220bca8d0b95b4bd37767779e7336":[1,0,1,1,16],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#a96e6e79a151a44fc216027c2afc9be95":[1,0,1,1,3],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#aa037f0aee458aec9d9fec0d710230c53":[1,0,1,1,7],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#ae0f10c1be572af5d813b897ea6251d71":[1,0,1,1,17],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#ae6a4775ff6faa6bbbf24697dd3e67935":[1,0,1,1,5],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#aeaab6ea8046f4a070eb0a3082b23a575":[1,0,1,1,2],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#af32c4ba813d3dce12b65f58f2453a615":[1,0,1,1,9],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#af58e88bce84c05a3428784e4313e2225":[1,0,1,1,1],
"classCGAL_1_1Delaunay__triangulation__on__sphere__traits__2.html#af8975d8dbc1d273b9070c8aebd8a72bd":[1,0,1,1,0],
"classCGAL_1_1Projection__on__sphere__traits__3.html":[1,0,1,2],
"classCGAL_1_1Projection__on__sphere__traits__3.html#a0b0e6576e8d12b2ac505341557211d53":[1,0,1,2,2],
"classCGAL_1_1Projection__on__sphere__traits__3.html#a20fe864cd37faa8230d413c717ea0ee3":[1,0,1,2,4],
"classCGAL_1_1Projection__on__sphere__traits__3.html#a375e158bb5c306d216132f663f00d847":[1,0,1,2,1],
"classCGAL_1_1Projection__on__sphere__traits__3.html#a423cc82220432d1ffedc48747a35ae5a":[1,0,1,2,0],
"classCGAL_1_1Projection__on__sphere__traits__3.html#aa4c8edc95f0f43fa12d5c9af783d8d39":[1,0,1,2,6],
"classCGAL_1_1Projection__on__sphere__traits__3.html#ab17ab4776f4ea2d929ecf5b4070141ea":[1,0,1,2,3],
"classCGAL_1_1Projection__on__sphere__traits__3.html#ac1b3f2510b150af5ee63c57a46b287e6":[1,0,1,2,7],
"classCGAL_1_1Projection__on__sphere__traits__3.html#acedb61884b014cd9cf1de5e3e5ff5111":[1,0,1,2,5],
"classCGAL_1_1Projection__on__sphere__traits__3.html#ae331b210f14afa75e4d0707886bacf9d":[1,0,1,2,8],
"classCGAL_1_1Triangulation__on__sphere__2.html":[1,0,1,3],
"classCGAL_1_1Triangulation__on__sphere__2.html#a045d9f92f669be1723600f8454a82da0":[1,0,1,3,37],
"classCGAL_1_1Triangulation__on__sphere__2.html#a09817eec2b69440e23dd95409fd6a18e":[1,0,1,3,31],
"classCGAL_1_1Triangulation__on__sphere__2.html#a0a5e73e02746d5805cd66ddbe8666b1f":[1,0,1,3,48],
"classCGAL_1_1Triangulation__on__sphere__2.html#a0b86fe9152f891272def95cacf6598bb":[1,0,1,3,63],
"classCGAL_1_1Triangulation__on__sphere__2.html#a0b9f9b2a795d7cbe57f9148fd9134bb1":[1,0,1,3,53],
"classCGAL_1_1Triangulation__on__sphere__2.html#a0c4985cf6b2bbc22d150c2473860de09":[1,0,1,3,44],
"classCGAL_1_1Triangulation__on__sphere__2.html#a10da4cc8bf560a04e12e88e707c0b80f":[1,0,1,3,14],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368":[1,0,1,3,29],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a085da3d409df0ce77cec7e3883048f84":[1,0,1,3,29,4],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a1fafd87c207c51dba17ff7bedbb9a7d5":[1,0,1,3,29,1],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a2ce43eac395c1e002fe8325b9679f7b0":[1,0,1,3,29,2],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a8e335bd92ce14c8b9faedeb7e1c7d32d":[1,0,1,3,29,6],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a8e685483f2b164f1fbaacd5b26b0d570":[1,0,1,3,29,5],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368a9054358245c71aec15608ef850a47696":[1,0,1,3,29,0],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1380bd7cd4c609ad52833f5e62778368ad9946ac171a3616baf474b692111ffdc":[1,0,1,3,29,3],
"classCGAL_1_1Triangulation__on__sphere__2.html#a13945f9b7898f1307150bf1645d0593d":[1,0,1,3,22],
"classCGAL_1_1Triangulation__on__sphere__2.html#a15b9150c44e9b2beb31c7d6af649b16c":[1,0,1,3,66],
"classCGAL_1_1Triangulation__on__sphere__2.html#a17cf0e76976af979a0f2590317a5ef81":[1,0,1,3,35],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1c66dcccc58c3e12e14ae675d2cb5030":[1,0,1,3,27],
"classCGAL_1_1Triangulation__on__sphere__2.html#a1d5958f1f28264f515e0592906482a36":[1,0,1,3,25],
"classCGAL_1_1Triangulation__on__sphere__2.html#a211810561992740f2350f7f0c5cd8a8a":[1,0,1,3,69],
"classCGAL_1_1Triangulation__on__sphere__2.html#a221c8c618dad2d73c69c0ac6fd70a463":[1,0,1,3,62],
"classCGAL_1_1Triangulation__on__sphere__2.html#a28294cf36820d583459bbaf8a912dea1":[1,0,1,3,81],
"classCGAL_1_1Triangulation__on__sphere__2.html#a2a9ceda7b558cb8543b76da093774536":[1,0,1,3,13],
"classCGAL_1_1Triangulation__on__sphere__2.html#a2d8b7777e2d52d559c2d852f022f4c15":[1,0,1,3,10],
"classCGAL_1_1Triangulation__on__sphere__2.html#a31e90961175ec0ddd72df7eb9440938d":[1,0,1,3,3],
"classCGAL_1_1Triangulation__on__sphere__2.html#a34a0c7dd74376c6ac1fd8f1f4925776d":[1,0,1,3,83],
"classCGAL_1_1Triangulation__on__sphere__2.html#a3782668eaabbbadbb34eb326c789cc57":[1,0,1,3,16],
"classCGAL_1_1Triangulation__on__sphere__2.html#a38ab81aa3d0471998c8095f585ebc6f0":[1,0,1,3,17],
"classCGAL_1_1Triangulation__on__sphere__2.html#a38d4d87e037ab84a86d40c8a58390801":[1,0,1,3,42],
"classCGAL_1_1Triangulation__on__sphere__2.html#a46cf5fb66ea5d670fdf5d909b4ad614a":[1,0,1,3,45],
"classCGAL_1_1Triangulation__on__sphere__2.html#a4972d0047f71cad49f3e01dae5ea5788":[1,0,1,3,43],
"classCGAL_1_1Triangulation__on__sphere__2.html#a4a921522cb870d1204cc6ea1632d5ff8":[1,0,1,3,15],
"classCGAL_1_1Triangulation__on__sphere__2.html#a53acc07d925f00b4a66979c9dbc99f29":[1,0,1,3,55],
"classCGAL_1_1Triangulation__on__sphere__2.html#a55718ca8fcf8b7118f5c8e66a06c1609":[1,0,1,3,41],
"classCGAL_1_1Triangulation__on__sphere__2.html#a56f201bc7550eebf57c41a364f4afc7e":[1,0,1,3,58],
"classCGAL_1_1Triangulation__on__sphere__2.html#a580f0b0bd168a95aed33f83d3d98c11d":[1,0,1,3,4],
"classCGAL_1_1Triangulation__on__sphere__2.html#a59e920fda7395347eeb9b83fd0ee8743":[1,0,1,3,9],
"classCGAL_1_1Triangulation__on__sphere__2.html#a5a7c4058b2a581af52820678a6d42c42":[1,0,1,3,2],
"classCGAL_1_1Triangulation__on__sphere__2.html#a5e784cdf403691ccb7f33d6548dea6df":[1,0,1,3,56],
"classCGAL_1_1Triangulation__on__sphere__2.html#a67bf1c3b2d51885487819d59622b4ef2":[1,0,1,3,65],
"classCGAL_1_1Triangulation__on__sphere__2.html#a6fd7a0383a88681376e8f6d32fc5aae0":[1,0,1,3,46],
"classCGAL_1_1Triangulation__on__sphere__2.html#a70648c8f333f770bf281fbed6610cfe3":[1,0,1,3,47],
"classCGAL_1_1Triangulation__on__sphere__2.html#a71262c6f8154440c0a46b35874743307":[1,0,1,3,23],
"classCGAL_1_1Triangulation__on__sphere__2.html#a713c3c5ecb019409d2fa5e18ff76a0ba":[1,0,1,3,7],
"classCGAL_1_1Triangulation__on__sphere__2.html#a75ae3c710864e895e56a33a324e7e217":[1,0,1,3,77],
"classCGAL_1_1Triangulation__on__sphere__2.html#a78b0e6bcf13d31f583f2dd80f7358508":[1,0,1,3,0],
"classCGAL_1_1Triangulation__on__sphere__2.html#a78e3e0f198bd1fc017dfbc8599cd6fa8":[1,0,1,3,52],
"classCGAL_1_1Triangulation__on__sphere__2.html#a79b3ccccb787702a803099dbb8d153c9":[1,0,1,3,8],
"classCGAL_1_1Triangulation__on__sphere__2.html#a7d140a659c5fae73282a9f1ac4923e68":[1,0,1,3,73],
"classCGAL_1_1Triangulation__on__sphere__2.html#a7ea02bf43866228055fbb8a97adde8d1":[1,0,1,3,28],
"classCGAL_1_1Triangulation__on__sphere__2.html#a82d32668830c6e80787aefbecd8c149b":[1,0,1,3,5],
"classCGAL_1_1Triangulation__on__sphere__2.html#a83cedc161f4fedc83790de4a5f1c8b66":[1,0,1,3,11],
"classCGAL_1_1Triangulation__on__sphere__2.html#a8aaacdcdb77ede1d09af712a37664cb6":[1,0,1,3,54],
"classCGAL_1_1Triangulation__on__sphere__2.html#a972d571584525af1ce6a9b8c1e0e7ff8":[1,0,1,3,82],
"classCGAL_1_1Triangulation__on__sphere__2.html#a9d518722559720a863563385011bfa95":[1,0,1,3,79],
"classCGAL_1_1Triangulation__on__sphere__2.html#aa7379e9213d72593fe5080f8e4407ebb":[1,0,1,3,60],
"classCGAL_1_1Triangulation__on__sphere__2.html#aa77bff97e3bd3adc78bb6efbd1a60c10":[1,0,1,3,33],
"classCGAL_1_1Triangulation__on__sphere__2.html#aa7cdafb9d3e3a037867283ad5354be67":[1,0,1,3,76],
"classCGAL_1_1Triangulation__on__sphere__2.html#aa98b1c1b47bbe751a02a42268cb013d9":[1,0,1,3,71],
"classCGAL_1_1Triangulation__on__sphere__2.html#ab04547a5ed211fb2af5ceb98272bcd3c":[1,0,1,3,18],
"classCGAL_1_1Triangulation__on__sphere__2.html#ab0bac2f0b31c53c793da28088cf74171":[1,0,1,3,21],
"classCGAL_1_1Triangulation__on__sphere__2.html#ab190d3933b157fcc4dab06ba7967e4c8":[1,0,1,3,75],
"classCGAL_1_1Triangulation__on__sphere__2.html#abb242907b37f4ee1bc02ce8ddbd91a41":[1,0,1,3,70],
"classCGAL_1_1Triangulation__on__sphere__2.html#abb251d75397d86feb4b29c520722a448":[1,0,1,3,30],
"classCGAL_1_1Triangulation__on__sphere__2.html#ac94b8b39af6976764fce6215a5077b42":[1,0,1,3,40],
"classCGAL_1_1Triangulation__on__sphere__2.html#ac9af62da049168122f6fb8fec2be6b2c":[1,0,1,3,80],
"classCGAL_1_1Triangulation__on__sphere__2.html#aca1455b13cb34a477aa901547b53f75e":[1,0,1,3,50],
"classCGAL_1_1Triangulation__on__sphere__2.html#ad23082a6839e0f7cabada1385928f4f3":[1,0,1,3,61],
"classCGAL_1_1Triangulation__on__sphere__2.html#ad2b2c32e7ab6f41b27fe94589514398b":[1,0,1,3,34],
"classCGAL_1_1Triangulation__on__sphere__2.html#ad6e3450f964ef4ce9a201e8fa4e3c9ac":[1,0,1,3,1],
"classCGAL_1_1Triangulation__on__sphere__2.html#ad7264cfa113ca9cad9022cf68e00c3c9":[1,0,1,3,72],
"classCGAL_1_1Triangulation__on__sphere__2.html#ad84dcc82df42f27cb53f87c076f306a5":[1,0,1,3,78],
"classCGAL_1_1Triangulation__on__sphere__2.html#ad8d8ed5aefab4009a5c04c9dd1e5a7bf":[1,0,1,3,51],
"classCGAL_1_1Triangulation__on__sphere__2.html#ad8d9c6bde74b4a2c346e9c3070bccc33":[1,0,1,3,49],
"classCGAL_1_1Triangulation__on__sphere__2.html#adac882d27a9c24379440ce68d79e6c92":[1,0,1,3,24],
"classCGAL_1_1Triangulation__on__sphere__2.html#adbf2438e4b0d78f6af214a37f6c262d9":[1,0,1,3,12],
"classCGAL_1_1Triangulation__on__sphere__2.html#adf4dde8d241fda17052d8eae08c2bdfc":[1,0,1,3,6],
"classCGAL_1_1Triangulation__on__sphere__2.html#ae41c9ffcd59aa74460032d6841ebe3ee":[1,0,1,3,32],
"classCGAL_1_1Triangulation__on__sphere__2.html#ae7f0deae8f142f4ec03e33ea794a373c":[1,0,1,3,59],
"classCGAL_1_1Triangulation__on__sphere__2.html#ae99403c8011c2b6cb084b4d38fec1bfc":[1,0,1,3,20],
"classCGAL_1_1Triangulation__on__sphere__2.html#aee414c526af8777c9f13dcf6c5df92ab":[1,0,1,3,36],
"classCGAL_1_1Triangulation__on__sphere__2.html#aee69f5d92abcf78a510beb697558c7eb":[1,0,1,3,74],
"classCGAL_1_1Triangulation__on__sphere__2.html#af0578ac9faf8649c54246b34e9c79ffe":[1,0,1,3,26],
"classCGAL_1_1Triangulation__on__sphere__2.html#af1541edded92f0d6ab0d7b3c105917e1":[1,0,1,3,39],
"classCGAL_1_1Triangulation__on__sphere__2.html#af54cb7ecf4defe0760c0e87e7acf317a":[1,0,1,3,67],
"classCGAL_1_1Triangulation__on__sphere__2.html#af60a99e81419bf43d457924d78697154":[1,0,1,3,64],
"classCGAL_1_1Triangulation__on__sphere__2.html#af858392dd142c5f7b024f4b4f1c6bb11":[1,0,1,3,57],
"classCGAL_1_1Triangulation__on__sphere__2.html#afbf28789c8f1721b8fa78e2cff05f344":[1,0,1,3,68],
"classCGAL_1_1Triangulation__on__sphere__2.html#afe67955ea61d7880cfde6711997c984a":[1,0,1,3,19],
"classCGAL_1_1Triangulation__on__sphere__2.html#aff0ff910e5a4c9158228518469a289fc":[1,0,1,3,38],
"classCGAL_1_1Triangulation__on__sphere__face__base__2.html":[1,0,2,0],
"classCGAL_1_1Triangulation__on__sphere__vertex__base__2.html":[1,0,2,1],
"classCGAL_1_1Triangulation__on__sphere__vertex__base__2.html#a227afa524eb82545345a243f03b1931d":[1,0,2,1,0],
"classDelaunayTriangulationOnSphereTraits__2.html":[1,0,0,0],
"classDelaunayTriangulationOnSphereTraits__2.html#a4c2775130ddb7a651c4fa16bfbe33140":[1,0,0,0,0],
"classDelaunayTriangulationOnSphereTraits__2.html#a7b05b6b8ddb6ccd34c33ae2b767d9728":[1,0,0,0,3],
"classDelaunayTriangulationOnSphereTraits__2.html#aab07b36d171f773d2745a9cfc4ea4e51":[1,0,0,0,1],
"classDelaunayTriangulationOnSphereTraits__2.html#ac9631aa2e4f6d34ef8b299a9681da6ff":[1,0,0,0,2],
"classTriangulationOnSphereFaceBase__2.html":[1,0,0,1],
"classTriangulationOnSphereFaceBase__2.html#a4b96ba868ac4e3eb26a6ea2a7ffe57fb":[1,0,0,1,1],
"classTriangulationOnSphereFaceBase__2.html#a6d4bd41e4848d65f826488f3619a930c":[1,0,0,1,3],
"classTriangulationOnSphereFaceBase__2.html#a793bf7ff535a925ce755a27436e3392b":[1,0,0,1,2],
"classTriangulationOnSphereFaceBase__2.html#afd01ca6f33579d6f8bae5cbb6b26c27e":[1,0,0,1,0],
"classTriangulationOnSphereTraits__2.html":[1,0,0,2],
"classTriangulationOnSphereTraits__2.html#a06b96068e1ef464447c8ae7f33ece934":[1,0,0,2,18],
"classTriangulationOnSphereTraits__2.html#a0f11c3631fc21caf7d4c174b9b1c29be":[1,0,0,2,21],
"classTriangulationOnSphereTraits__2.html#a11999045009bb61c10e4ff18cd5d82d7":[1,0,0,2,17],
"classTriangulationOnSphereTraits__2.html#a254c6504bb49953d984a00e377c55469":[1,0,0,2,22],
"classTriangulationOnSphereTraits__2.html#a265864f8a07206bdea6fe3f03491c708":[1,0,0,2,25],
"classTriangulationOnSphereTraits__2.html#a37cc151d3bf935923db004e62528fdbf":[1,0,0,2,26],
"classTriangulationOnSphereTraits__2.html#a39d523963d051855ec34f613b57ec764":[1,0,0,2,23],
"classTriangulationOnSphereTraits__2.html#a40a502e3a9bc2191293f585823d99aad":[1,0,0,2,12],
"classTriangulationOnSphereTraits__2.html#a4825fda1c98fd9299f27634a60870a43":[1,0,0,2,10],
"classTriangulationOnSphereTraits__2.html#a4b7c44f23634bab698794c56e3992ba2":[1,0,0,2,4],
"classTriangulationOnSphereTraits__2.html#a6291a049ad1d64ef37dcebc65b422cb5":[1,0,0,2,27],
"classTriangulationOnSphereTraits__2.html#a6822847cfa27ef08ddd0edb586ded61f":[1,0,0,2,24],
"classTriangulationOnSphereTraits__2.html#a6f12171853e0d7ea65fdd8766d3ee6b4":[1,0,0,2,13],
"classTriangulationOnSphereTraits__2.html#a79949403017b5bfa230631f9bdb910d5":[1,0,0,2,30],
"classTriangulationOnSphereTraits__2.html#a7a401b7328b16e3a1f1ca8b24707beb8":[1,0,0,2,3],
"classTriangulationOnSphereTraits__2.html#a90141dcefb6dc3866c6469651ab0e1ea":[1,0,0,2,6],
"classTriangulationOnSphereTraits__2.html#a9460c4f1ee9a08919f56ca8f91660e4e":[1,0,0,2,8],
"classTriangulationOnSphereTraits__2.html#a963cd8929ba800b5f4802baf56d3292b":[1,0,0,2,31],
"classTriangulationOnSphereTraits__2.html#a9882fad4564dbce875f1e06b3f7d54cd":[1,0,0,2,0],
"classTriangulationOnSphereTraits__2.html#aa0478d05495c0c088cc37a2a95834757":[1,0,0,2,29],
"classTriangulationOnSphereTraits__2.html#aa5355516229e1b6b8375b955e55b8951":[1,0,0,2,5],
"classTriangulationOnSphereTraits__2.html#aa6f3e25de9e17334dc3b92b949e6dad7":[1,0,0,2,11],
"classTriangulationOnSphereTraits__2.html#ab72e578444dcbdb784495ea2bfefbf16":[1,0,0,2,7],
"classTriangulationOnSphereTraits__2.html#aba204e427e1c7909743e8bc48d830365":[1,0,0,2,16],
"classTriangulationOnSphereTraits__2.html#abcc0a344f8ba2c372860cc21803c6c50":[1,0,0,2,28],
"classTriangulationOnSphereTraits__2.html#ac5d21bd926fc9bec3f7d01985e386018":[1,0,0,2,20],
"classTriangulationOnSphereTraits__2.html#ac6636154ff686544a80457830accfb78":[1,0,0,2,19],
"classTriangulationOnSphereTraits__2.html#adbe715f38f73ac1e072a8b9812bd9b2c":[1,0,0,2,2],
"classTriangulationOnSphereTraits__2.html#adffcfb8d923e5b155ce854c3441c4fcb":[1,0,0,2,9],
"classTriangulationOnSphereTraits__2.html#aed86feab29ceb6077f39c5c4122211a3":[1,0,0,2,15],
"classTriangulationOnSphereTraits__2.html#afb850a8f2d2a75cb47ddbe25f15d6665":[1,0,0,2,14],
"classTriangulationOnSphereTraits__2.html#afd2b488c9d27c9de48c0d4bb27202b11":[1,0,0,2,1],
"classTriangulationOnSphereVertexBase__2.html":[1,0,0,3],
"classTriangulationOnSphereVertexBase__2.html#a259571ec551badb044db4084d1ce77ce":[1,0,0,3,0],
"classTriangulationOnSphereVertexBase__2.html#a28712600502a69c98a8bff0bea5762e3":[1,0,0,3,3],
"classTriangulationOnSphereVertexBase__2.html#a5f5376bf14e89536dc3aac2490903b25":[1,0,0,3,7],
"classTriangulationOnSphereVertexBase__2.html#a799485c9be0e7df245141c294144796d":[1,0,0,3,2],
"classTriangulationOnSphereVertexBase__2.html#a86962fd1a1aa4b624fcadf18e869c4ac":[1,0,0,3,6],
"classTriangulationOnSphereVertexBase__2.html#a9071bd6f4f5d7b8bd929f0cc84b80063":[1,0,0,3,5],
"classTriangulationOnSphereVertexBase__2.html#ac70b36a15bb1e779b5b07fc4742d800c":[1,0,0,3,4],
"classTriangulationOnSphereVertexBase__2.html#ac74a14d8067dc85377196f733981afa8":[1,0,0,3,1],
"examples.html":[4],
"group__PkgTriangulationOnSphere2Concepts.html":[1,0,0],
"group__PkgTriangulationOnSphere2Ref.html":[1,0],
"group__PkgTriangulationOnSphere2TriangulationClasses.html":[1,0,1],
"group__PkgTriangulationOnSphere2VertexFaceClasses.html":[1,0,2],
"index.html":[],
"index.html":[0],
"index.html#Section_2D_ToS_Definitions":[0,0],
"index.html#Section_2D_ToS_Design":[0,3],
"index.html#Section_2D_ToS_Embedding":[0,1,3],
"index.html#Section_2D_ToS_Ex_Basic":[0,2,0],
"index.html#Section_2D_ToS_Ex_Exact":[0,2,1],
"index.html#Section_2D_ToS_Ex_Project":[0,2,2],
"index.html#Section_2D_ToS_Ex_Range":[0,2,3],
"index.html#Section_2D_ToS_Examples":[0,2],
"index.html#Section_2D_ToS_Ghost":[0,1,0],
"index.html#Section_2D_ToS_Implementation":[0,1],
"index.html#Section_2D_ToS_Imprecision":[0,0,0],
"index.html#Section_2D_ToS_Lowdim":[0,1,2],
"index.html#Section_2D_ToS_Traits":[0,1,1],
"modules.html":[1],
"pages.html":[]
};
